# Configure your hosts

## Basic configurations

When defining a host, you need to provide it with a hostname. It can be the domain of your server or its IP address.

```php
host('domain.com')
```

You can also give your hosts a stage and/or several roles.

```php
host('domain.com')
    ->stage('production')
    ->roles('app');
```

You can use those later on to filter hosts when executing tasks.

```bash
php artisan deploy production
php artisan deploy --roles=app
php artisan deploy --hosts='domain.com'
```

Finally, you can set up and override any options locally within a host using the `set()` method. In the following example, `key` equals 'global' for every hosts except for the 'domain.com' host where `key` equals 'local'.

```php
set('key', 'global');

host('domain.com')
    ->set('deploy_path', '~/app')
    ->set('key', 'local');
```

## Authentication

By default, deployer will use your `~/.ssh/id_rsa` key. If you want a custom SSH set up, use the following methods.

```php
host('domain.com')
    // ...
    ->user('root')
    ->configFile('~/.ssh/config')
    ->identityFile('~/.ssh/id_rsa')
    ->forwardAgent(true)
    ->multiplexing(true)
    ->addSshOption('key', 'value');
```

## Define your hosts in yaml

Create a `hosts.yml` file...

```yaml
domain.com:
  stage: production
  roles: app
  deploy_path: ~/app
```

and import it in your `deploy.php`.

```php
inventory('hosts.yml');
```

There is a lot more you can do with your hosts. Read more on the [official Deployer documentation](https://deployer.org/docs/hosts).